# ICON_OMCI

The **O**ASIS3-**M**CT **C**oupling **I**nterface for **ICON**-CLM.

## Synopsis

It is the new external coupling interface for the `ICON-CLM` model (Pham et al., 2021) using the OASIS3-MCT coupler (Valcke et al., 2015) to couple ICON-CLM with the ocean model NEMO (Madec et al., 2017) and the hydrological discharge model HD (Hagemann et al., 2020; Hagemann and Ho-Hagemann, 2021) in the `GCOAST-AHOI` coupled system model (Ho-Hagemann et al., 2020), a sub-set of the **G**eesthacht **C**oupled c**OA**stal model **S**ys**T**em [GCOAST](https://hereon.de/institutes/coastal_systems_analysis_modeling/research/gcoast/index.php.en).

ICON-CLM is the regional climate model that has been developed by the Deutscher Wetterdienst (DWD) and the Climate Limited-area Modeling Community (CLM-Community) since 2017. ICON-CLM is the
Climate Mode of `ICON-LAM` (ICON-Limited Area Mode, based on the numerical weather prediction model `ICON-NWP`) of the ICON (Icosahedral Nonhydrostatic) model (Zängl et al., 2015). ICON has been developed since 2001 as the result of a cooperation between DWD and Max Planck Institute for Meteorology (MPI-M) (see [an overview](https://code.mpimet.mpg.de/projects/iconpublic) of ICON). It currently comprises two versions (ICON-NWP, ICON-ESM) that share the same dynamics but have different physical packages. ICON-ESM comprises atmospheric, land, river routing, ocean-sea ice and biogeochemical compartments, while the Aerosols and Reactive Trace gases (ART) model was implemented into ICON-NWP.

ICON can be set up to operate on different high performance computing systems such as at the German Climate Computing Center (DKRZ, Hamburg, Germany), at DWD (Offenbach, Germany) or at FZJ (Forschung Zentrum Jülich, Germany). ICON-CLM currently contains a set of technical adaptations for climate applications.


## Motivation

Including major compartments of the climate system, ICON-ESM has YAC (Yet Another Coupler; Hanke et al., 2016) to couple the component models together. Unfortunately, up to date, the YAC coupling is available only for ICON-A (i.e. the global atmospheric ICON model with MPI-M ECHAM physics) to couple with ICON-O (i.e. the global ocean model of ICON) and JSBACH (i.e. the land surface model, with the river routing from HD as subroutines). There is not yet a YAC coupling interface implemented in the ICON-NWP (i.e. the atmospheric ICON model with the numerical weather prediction physics of DWD), and therefore, neither in ICON-CLM. Even if YAC is available in ICON-CLM in the future, ICON-CLM cannot be coupled with other models which utilize different couplers such as OASIS or Earth System Modeling Framework (ESMF; Hill et al., 2004).

In `GCOAST-AHOI`, the regional ocean model NEMO and the hydrological discharge model HD both already have an OASIS3-MCT interface which has been used to couple with the regional atmospheric model COSMO-CLM (see Will et al., 2017). To couple ICON-CLM with NEMO and HD, it is necessary to implement `ICON_OMCI` into ICON-CLM. This version of `ICON_OMCI` was implemented into the original ICON version `icon-2.6.4`. The implementation was conducted as a patch application.

The `ICON_OMCI` can be applied to couple ICON-CLM with any other ocean model which also has the OASIS3-MCT interface.


## Installation of the Patch
+ Step 1: Prepare a local directory, for example

  ```bash
      mkdir -p userpath/ICON_OAS
  ```
  
+ Step 2: download the ICON source code of the released version `icon-v2.6.4` from the [ICON download page](https://code.mpimet.mpg.de/projects/icon-downloads/files) to your local directory `userpath/ICON_OAS`.
  If you do not yet have access, i.e. no private license, go to the [License page](https://code.mpimet.mpg.de/projects/iconpublic/wiki/Instructions_to_obtain_the_ICON_model_code_with_a_personal_non-commercial_research_license) first. Then
  
  ```bash
      cp icon-2.6.4.tar.xz userpath/ICON_OAS/.
  ```

+ Step 3: unzip the tar file `icon-2.6.4.tar.xz`
  
  ```bash
      cd userpath/ICON_OAS
      tar -xvf icon-2.6.4.tar.xz
  ```

+ Step 4: copy the patch file `icon-2.6.4_OASIS.patch` into `userpath/ICON_OAS`
  
  ```bash
      cp icon-2.6.4_OASIS.patch userpath/ICON_OAS/.
  ```

+ Step 5: run the `patch` command inside the `icon-2.6.4` to apply the patch on ICON
  
  ```bash
      cd userpath/ICON_OAS/icon-2.6.4
      patch -fp0 < userpath/ICON_OAS/icon-2.6.4_OASIS.patch
  ```

+ Step 6: change the name of `icon-2.6.4` to `icon-2.6.4_OAS` to not mix up with the original version
  
  ```bash
      cd userpath/ICON_OAS
      mv icon-2.6.4 icon-2.6.4_OAS
  ```

## Compilation of ICON with the OASIS3-MCT interface
  After finishing the installation of the patch, one should obtain the ICON source code `icon-v2.6.4_OAS` with the OASIS interface included. The model can be compiled directly on the high computing system `Mistral` at DKRZ. For other computing systems, please follow some extra notes given below.

+ Step 1: adapt the `paths.inc` and `mistral.intel*` in the directory `compile_ICON/`.
  In case of the DWD's or other computing system, please do NOT use the mistral.intel* but copy an environment setting file under `config/xxx` (with `xxx` being an option for the computing system) to this `compile_ICON/` directory and modify the file `compile_ICON.sh` correspondingly.
  There are some options for `xxx` such as `buildbot`, `clm`, `cscs`, `dkrz`, `dwd`, `ecmwf`, `ethz`, `generic`, `kit`, `mpim` under `config/`.

  Note that one can see what has been modified in the `mistral.intel*` due to the OASIS interface by comparing these files with the original ones at `config/dkrz`. Similarly, some lines in the file `icon-2.6.4_OAS/configure` were added due to the OASIS interface. One can see them by using this command:

  
  ```bash
      grep -i OAS icon-2.6.4_OAS/configure
  ```

+ Step 2: adapt the path `all_build` in `compile_ICON.sh` to the directory which will contain the build directory

+ Step 3: inside the directory `icon-2.6.4_OAS`, prepare a shell script file (e.g. `compile_ICON_OAS.sh`) which includes these line:
  
  ```bash
  	reconfig="yes"		# for the first time only
  	#reconfig="no"		# if no re-configuration is needed
  	coupling_mode="yes"	# to compile with OASIS
  	#coupling_mode="no"	# to compile without OASIS
  	ECRAD="yes" 		# ecRad radiation scheme is used
  	ART="no"	        # ART is not used
  	./compile_ICON.sh ${reconfig} ${coupling_mode} ${ECRAD} ${ART}
  ```

+ Step 4: Now run the shell script to compile ICON with the OASIS interface
  
  ```bash
    ./compile_ICON_OAS.sh
  ```

## Acknowledgements
I appreciate the shared experience of Stefan Poll from Forschung Zentrum Jülich (FZJ) on setting up the OASIS coupling interface in ICON-LES within the Terrestrial System Model Platform (TSMP). I'm grateful to Irina Fast (DKRZ) for her support to debug some parts of the OASIS interface on Mistral. Moreover, I thank Daniel Rieger (DWD) for his support in clarifying questions regarding the handling of variables in ICON-NWP. I would like to express my thanks to Burkhardt Rockel (Hereon) for providing the Starter Package for ICON-CLM Experiments (SPICE) which is helpful to conduct experiments with ICON-CLM and the OASIS interface.

## References
+ Hagemann, S., T. Stacke and H.T.M. Ho-Hagemann, High resolution discharge simulations over Europe and the Baltic Sea catchment. Front. Earth Sci., 8:12. https://doi.org/10.3389/feart.2020.00012, 2020.
+ Hagemann, S., and Ho-Hagemann, H.T.M.: The Hydrological Discharge Model - a river runoff component for offline and coupled model applications (5.1.0). Zenodo. https://doi.org/10.5281/zenodo.5707587, 2021
+ Hanke, M., Redler, R., Holfeld, T., and Yastremsky, M.: YAC 1.2.0: new aspects for coupling software in Earth system modelling. Geoscientific Model Development, 9, 2755-2769. DOI:10.5194/gmd-9-2755-201, 2016
+ Hill, C., DeLuca, C., Balaji, Suarez, M., and Da Silva, A.: The architecture of the Earth System Modeling Framework, Computing in Science Engineering, 6, 18–28, https://doi.org/10.1109/MCISE.2004.1255817, 2004.
+ Ho-Hagemann, H. T. M., Hagemann, S., Grayek, S., Petrik, R., Rockel, B., Staneva, J., Feser, F., and Schrum, C.: Internal model variability in the regional coupled system model GCOAST-AHOI, Atmosphere, 11, 227, https://doi.org/10.3390/atmos11030227, 2020.
+ Madec, G., Bourdallé-Badie, R., Bouttier, P.-A., Bricaud, C., Bruciaferri, D., Calvert, D., Chanut, J., Clementi, E., Coward, A., Delrosso, D., Ethé, C., Flavoni, S., Graham, T., Harle, J., Iovino, D., Lea, D., Lévy, C., Lovato, T., Martin, N., Masson, S., Mocavero, S., Paul, J., Rousset, C., Storkey, D., Storto, A., and Vancoppenolle, M.: NEMO ocean engine (Version v3.6-patch), Tech. rep., Pôle De Modélisation De L’institut Pierre-simon Laplace (IPSL), Zenodo, https://doi.org/10.5281/ZENODO.3248739, 2017.
+ Pham, T. V., Steger, C., Rockel, B., Keuler, K., Kirchner, I., Mertens, M., Rieger, D., Zängl, G., and Früh, B.: ICON in Climate Limited-area Mode (ICON release version 2.6.1): a new regional climate model, Geosci. Model Dev., 14, 985–1005, https://doi.org/10.5194/gmd-14-985-2021, 2021. 
+ Valcke, S.; Craig, T.; Coquart, L. OASIS3-MCT user guide, OASIS3-MCT 3.0. Technical Report TR/CMGC/15/38, CERFACS, Toulouse, France, CERFACS/CNRS SUC URA No 1875, 2015
+ Will, A.; Akhtar, N.; Brauch, J.; Breil, M.; Davin, E.; Ho-Hagemann, H.T.M.; Maisonnave, E.; Thürkow, M.; Weiher, S. The COSMO-CLM 4.8 regional climate model coupled to regional ocean, land surface and global earth system models using OASIS3-MCT: Description and performance. Geosci. Model Dev. 2017, 10, 1549–1586. doi:10.5194/gmd-10-1549-2017.
+ Zängl, G., Reinert, D., Rípodas, P., and Baldauf, M.: The ICON (ICOsahedral Non-hydrostatic) modelling framework of DWD and MPI-M: Description of the non-hydrostatic dynamical core, Q. J. Roy. Meteor. Soc., 141, 563–579, https://doi.org/10.1002/qj.2378, 2015.

## Contributors

* Ha Thi Minh Ho-Hagemann (ha.hagemann@hereon.de)

## License

ICON_OMCI<br>
Copyright (C) 2021 Institute of Coastal Systems - Analysis and Modelling, Helmholtz-Zentrum Hereon<br>

This program is licensed under the Apache License, Version 2.0 (http://www.apache.org/licenses/LICENSE-2.0)

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Apache License for more details.


